![Tests](https://github.com/akcelero/eth-hub/actions/workflows/run-tests.yml/badge.svg?query=branch%3Amaster)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
